@@ -1,4 +1,5 @@
 from django.db import models
+from django.utils import timezone
 from django.conf import settings as django_settings
 from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
@@ -31,6 +32,31 @@ class Book(models.Model):
     def __str__(self):
         return self.title
 
+    @classmethod
+    def from_db(cls, db, field_names, values):
+        instance = super().from_db(db, field_names, values)
+        instance._loaded_values = dict(zip(field_names, values))
+        return instance
+
+    def has_changed(self):
+        if (
+            self._loaded_values["title"] != self.title
+            or self._loaded_values["metadata"] != self.metadata
+            or self._loaded_values["settings"] != self.settings
+            or self._loaded_values["cover_image_id"] != self.cover_image_id
+            or self._loaded_values["owner_id"] != self.owner_id
+        ):
+            return True
+        else:
+            return False
+
+    def save(self, *args, **kwargs):
+        if ("force_update" in kwargs and kwargs["force_update"]) or (
+            not self._state.adding and self.has_changed()
+        ):
+            self.updated = timezone.now()
+        return super().save(*args, **kwargs)
+
 
 class Chapter(models.Model):
     text = models.ForeignKey(Document, on_delete=models.deletion.CASCADE)
