@@ -2,7 +2,6 @@ import json
 import time
 
 from django.http import JsonResponse, HttpRequest
-from django.utils import timezone
 from django.contrib.auth.decorators import login_required
 from django.db import transaction
 from django.contrib.auth import get_user_model
@@ -160,7 +159,22 @@ def list(request):
 
 
 def set_chapters(book, chapters, user):
-    book.chapter_set.all().delete()
+    changed = False
+    current_chapters = book.chapter_set.all().order_by("number")
+    if len(current_chapters) != len(chapters):
+        changed = True
+    else:
+        for i, cur_chap in enumerate(current_chapters):
+            if (
+                cur_chap.text_id != chapters[i]["text"]
+                or cur_chap.number != chapters[i]["number"]
+                or cur_chap.part != chapters[i]["part"]
+            ):
+                changed = True
+                break
+    if not changed:
+        return
+    current_chapters.delete()
     for chapter in chapters:
         new_chapter = Chapter(
             book=book,
@@ -200,6 +214,7 @@ def set_chapters(book, chapters, user):
                     user_id=book.owner.id,
                     rights="read",
                 )
+        book.save(force_update=True)
     return
 
 
@@ -265,7 +280,6 @@ def save(request):
         book = Book.objects.get(id=book_obj["id"])
         if book.owner == request.user:
             has_book_write_access = True
-            book.updated = timezone.now()
             book.path = book_obj["path"]
         else:
             access_right = book.bookaccessright_set.filter(
@@ -275,7 +289,6 @@ def save(request):
             ).first()
             if access_right:
                 has_book_write_access = True
-                book.updated = timezone.now()
                 access_right.path = book_obj["path"]
                 access_right.save()
     has_coverimage_access = False
